@@ -8,7 +8,7 @@ import unittest
 import os
 import re
 import time
-
+from contextlib import contextmanager
 
 from ..graphspell.ibdawg import IBDAWG
 from ..graphspell.echo import echo
@@ -18,6 +18,36 @@ from . import phonet
 from . import mfsp
 
 
+@contextmanager
+def timeblock (label, hDst):
+    "performance counter (contextmanager)"
+    start = time.perf_counter()
+    try:
+        yield
+    finally:
+        end = time.perf_counter()
+        print('{} : {}'.format(label, end - start))
+        if hDst:
+            hDst.write("{:<12.6}".format(end-start))
+
+
+def perf (sVersion, hDst=None):
+    "performance tests"
+    print("\nPerformance tests")
+    gce.load()
+    gce.parse("Texte sans importance… utile pour la compilation des règles avant le calcul des perfs.")
+
+    spHere, _ = os.path.split(__file__)
+    with open(os.path.join(spHere, "perf.txt"), "r", encoding="utf-8") as hSrc:
+        if hDst:
+            hDst.write("{:<12}{:<20}".format(sVersion, time.strftime("%Y.%m.%d %H:%M")))
+        for sText in ( s.strip() for s in hSrc if not s.startswith("#") and s.strip() ):
+            with timeblock(sText[:sText.find(".")], hDst):
+                gce.parse(sText)
+        if hDst:
+            hDst.write("\n")
+
+
 def _fuckBackslashUTF8 (s):
     "fuck that shit"
     return s.replace("\u2019", "'").replace("\u2013", "–").replace("\u2014", "—")
@@ -176,8 +206,8 @@ class TestGrammarChecking (unittest.TestCase):
                 print("Unexpected errors:", nError)
         # untested rules
         i = 0
-        for sOpt, sLineId, sRuleId in gce.listRules():
-            if sOpt != "@@@@" and sLineId not in self._aTestedRules and not re.search("^[0-9]+[sp]$|^[pd]_", sRuleId):
+        for _, sOpt, sLineId, sRuleId in gce.listRules():
+            if sOpt != "@@@@" and sRuleId not in self._aTestedRules and not re.search("^[0-9]+[sp]$|^[pd]_", sRuleId):
                 echo(sLineId + "/" + sRuleId, end= ", ")
                 i += 1
         if i:
@@ -201,7 +231,7 @@ class TestGrammarChecking (unittest.TestCase):
             sRes = sRes[:dErr["nStart"]] + "~" * (dErr["nEnd"] - dErr["nStart"]) + sRes[dErr["nEnd"]:]
             sListErr += "    * {sLineId} / {sRuleId}  at  {nStart}:{nEnd}\n".format(**dErr)
             lAllSugg.append("|".join(dErr["aSuggestions"]))
-            self._aTestedRules.add(dErr["sLineId"])
+            self._aTestedRules.add(dErr["sRuleId"])
             # test messages
             if "<start>" in dErr["sMessage"] or "<end>" in dErr["sMessage"]:
                 print("\n# Line num : " + dErr["sLineId"] + \
@@ -218,37 +248,6 @@ class TestGrammarChecking (unittest.TestCase):
         return sRes
 
 
-from contextlib import contextmanager
-@contextmanager
-def timeblock (label, hDst):
-    "performance counter (contextmanager)"
-    start = time.perf_counter()
-    try:
-        yield
-    finally:
-        end = time.perf_counter()
-        print('{} : {}'.format(label, end - start))
-        if hDst:
-            hDst.write("{:<12.6}".format(end-start))
-
-
-def perf (sVersion, hDst=None):
-    "performance tests"
-    print("\nPerformance tests")
-    gce.load()
-    gce.parse("Texte sans importance… utile pour la compilation des règles avant le calcul des perfs.")
-
-    spHere, _ = os.path.split(__file__)
-    with open(os.path.join(spHere, "perf.txt"), "r", encoding="utf-8") as hSrc:
-        if hDst:
-            hDst.write("{:<12}{:<20}".format(sVersion, time.strftime("%Y.%m.%d %H:%M")))
-        for sText in ( s.strip() for s in hSrc if not s.startswith("#") and s.strip() ):
-            with timeblock(sText[:sText.find(".")], hDst):
-                gce.parse(sText)
-        if hDst:
-            hDst.write("\n")
-
-
 def main():
     "start function"
     unittest.main()
